@@ -18,21 +18,23 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module GZiptest(tests) where
 import Test.HUnit
-import MissingH.FileArchive.GZip
-import MissingH.Compression.Inflate
-import MissingH.IO.Binary
+import System.FileArchive.GZip
+import System.FilePath
+import Data.Compression.Inflate
+import System.IO.Binary
 import System.IO
-import MissingH.Either
+import Data.Either.Utils
 import Data.List
 
 mf fn exp conf = TestLabel fn $ TestCase $
-                     do c <- readBinaryFile ("testsrc/gzfiles/" ++ fn)
+                     do c <- readBinaryFile $
+                          joinPath ["testsrc", "gzfiles", fn]
                         assertEqual "" exp (conf c)
 
 {-
-import MissingH.FileArchive.GZip
+import System.FileArchive.GZip
 import System.IO
-import MissingH.Either
+import Data.Either.Utils
 
 main = do
        c <- hGetContents stdin
