@@ -18,11 +18,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module HVFStest(tests) where
 import Test.HUnit
-import MissingH.IO.HVIO
-import MissingH.IO.HVFS
-import MissingH.IO.HVFS.InstanceHelpers
-import MissingH.IO.HVFS.Combinators
-import MissingH.HUnit
+import System.IO.HVIO
+import System.IO.HVFS
+import System.IO.HVFS.InstanceHelpers
+import System.IO.HVFS.Combinators
+import Test.HUnit.Utils
 import System.IO
 import System.IO.Error
 import Control.Exception
